@@ -36,13 +36,14 @@ class DeepTranscriptParameters(ConverterParameters):
         <li>`AudioFile`: an audio file (wav, mp3, flac, etc...)<br/>
         <li>`YoutubeUrls`: A plain text file with a list of Youtube urls one by line.""",
     )
+    duration: int = Field(300, description="Limit the duration (in seconds) of the audio (0 means no limit)")
 
 
 class DeepTranscriptConverter(ConverterBase):
     """DeepTranscript converter ."""
 
     @staticmethod
-    def process_audio_file(source, tmpdir, docs):
+    def process_audio_file(source, tmpdir, duration, docs):
         kind = filetype.guess(source.file)
         source.file.seek(0)
         if (
@@ -59,7 +60,7 @@ class DeepTranscriptConverter(ConverterBase):
                     tmp_file.write(inputs)
                 else:
                     codec = "opus" if kind.extension == "webm" else None
-                    segment = AudioSegment.from_file(source.file, codec=codec)
+                    segment = AudioSegment.from_file(source.file, codec=codec, duration=duration)
                     # check audio export
                     segment.export(tmp_file, format="wav")
             except BaseException as err:
@@ -94,9 +95,14 @@ class DeepTranscriptConverter(ConverterBase):
         return doc
 
     @staticmethod
-    def process_youtube_list(source, tmpdir, docs):
+    def process_youtube_list(source, tmpdir, duration, docs):
         inputs = source.file.readlines()
         urls = []
+
+        ffmpeg_options = ["-ar", "8000", "-ac", "1"]
+        if duration is not None:
+            ffmpeg_options.append("-t")
+            ffmpeg_options.append(f"{duration}")
         for line in inputs:
             line = (
                 str(line, "utf-8").strip() if isinstance(line, bytes) else line.strip()
@@ -120,7 +126,7 @@ class DeepTranscriptConverter(ConverterBase):
                     }
                 ],
                 "postprocessor_args": {
-                    "extractaudio+ffmpeg_o1": ["-ar", "8000", "-ac", "1"]
+                    "extractaudio+ffmpeg_o1": ffmpeg_options
                 },
             }
             with YoutubeDL(ydl_opt) as ydl:
@@ -153,14 +159,14 @@ class DeepTranscriptConverter(ConverterBase):
             resp.raise_for_status()
 
         webhook = WebhookServer()
-
+        duration = None if params.duration == 0 else params.duration
         docs = {}
         with TemporaryDirectory() as tmpdir:
             tmp_dir = Path(tmpdir)
             if params.input_format == InputFormat.AudioFile:
-                self.process_audio_file(source, tmpdir, docs)
+                self.process_audio_file(source, tmpdir, duration, docs)
             else:
-                self.process_youtube_list(source, tmpdir, docs)
+                self.process_youtube_list(source, tmpdir, duration, docs)
 
             if docs:
                 wav_files = list(tmp_dir.glob("*.wav"))
